boofun.families.base
====================

.. automodule:: boofun.families.base


   .. rubric:: Functions

   .. autosummary::

      geometric_ltf_family
      harmonic_ltf_family
      power_ltf_family
      uniform_ltf_family

   .. rubric:: Classes

   .. autosummary::

      FamilyMetadata
      FunctionFamily
      InductiveFamily
      WeightPatternFamily
